@@ -2,7 +2,6 @@ import pandas as pd
 import numpy as np
 import re
 import json
-from demyst.common import is_na, is_value
 
 # These pseudo-attributes are removed from the final report
 PSEUDO_ATTRS=["client_id", "error", "is_hit", "row_id"]
@@ -203,10 +202,13 @@ def report(enriched, columns=[]):
     # Ignore columns without a dot.
     # https://github.com/DemystData/demyst-python/issues/555
     output_cols = [c for c in enriched.columns if (not c.startswith("inputs.")) and ("." in c)]
-    
+
     attributes = do_report(enriched[output_cols])
 
     if len(columns) > 0:
         attributes = filter_columns(attributes, columns)
 
     return attributes
+
+def is_value(value):
+    return not(pd.isna(value) or (isinstance(value, str) and value.strip() == ""))
